var _globalAttributes = [
  _Attribute(
    name: 'accesskey',
    description: 'Keyboard shortcut to activate or focus element',
  ),
  _Attribute(
    name: 'autocapitalize',
    description:
        'Recommended autocapitalization behavior (for supported input methods)',
  ),
  _Attribute(
    name: 'class',
    description: 'The element\'s class',
  ),
  _Attribute(
    name: 'contenteditable',
    description: 'Whether the element is editable',
  ),
  _Attribute(
    name: 'dir',
    description: 'The text directionality of the element',
  ),
  _Attribute(
    name: 'draggable',
    description: 'Whether the element is draggable',
  ),
  _Attribute(
    name: 'enterkeyhint',
    description: 'Hint for selecting an enter key action',
  ),
  _Attribute(
    name: 'hidden',
    description: 'Whether the element is relevant',
  ),
  _Attribute(
    name: 'id',
    description: 'The element\'s id',
  ),
  _Attribute(
    name: 'inputmode',
    description: 'Integrity metadata used in Subresource Integrity checks',
  ),
  _Attribute(
    name: 'is',
    description: 'Creates a customized built-in element',
  ),
  _Attribute(
    name: 'itemid',
    description: 'Global identifier for a microdata item',
  ),
  _Attribute(
    name: 'itemprop',
    description: 'Property names of a microdata item',
  ),
  _Attribute(
    name: 'itemref',
    description: 'Referenced elements',
  ),
  _Attribute(
    name: 'itemscope',
    description: 'Referenced elements',
  ),
  _Attribute(
    name: 'itemtype',
    description: 'Item types of a microdata item',
  ),
  _Attribute(
    name: 'lang',
    description: 'Language of the element',
  ),
  _Attribute(
    name: 'nonce',
    description: 'Cryptographic nonce used in Content Security Policy checks',
  ),
  _Attribute(
    name: 'slot',
    description: 'The element\'s slot',
  ),
  _Attribute(
    name: 'spellcheck',
    description:
        'Whether the element is to have its spelling and grammar checked',
  ),
  _Attribute(
    name: 'style',
    description: 'Presentational and formatting instructions',
  ),
  _Attribute(
    name: 'tabindex',
    description:
        'Whether the element is focusable, and the relative order of the element for the purposes of sequential focus navigation',
  ),
  _Attribute(
    name: 'title',
    description: 'Advisory information for the element',
  ),
  _Attribute(
    name: 'translate',
    description:
        'Whether the element is to be translated when the page is localized',
  )
];

class _Attribute {
  _Attribute({this.name, this.description});

  String name;
  String description;
}

class _Tag {
  _Tag(this.tag, {this.attributes, this.isVoidElement = false}) {
    attributes = List<_Attribute>.from(_globalAttributes);
  }

  String tag;
  List<_Attribute> attributes;
  bool isVoidElement;
}

/// A list of all HTML elements along with their valid attributes.
var typedElements = [
  _Tag("a")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'href',
          description: 'Address of the hyperlink',
        ),
        _Attribute(
          name: 'target',
          description: 'Browsing context for hyperlink navigation',
        ),
        _Attribute(
          name: 'download',
          description:
              'Whether to download the resource instead of navigating to it, and its file name if so',
        ),
        _Attribute(
          name: 'ping',
          description: 'URLs to ping',
        ),
        _Attribute(
          name: 'rel',
          description:
              'Relationship between the location in the document containing the hyperlink and the destination resource',
        ),
        _Attribute(
          name: 'hreflang',
          description: 'Language of the linked resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Hint for the type of the referenced resource',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
      ],
    ),
  _Tag("abbr"),
  _Tag("address"),
  _Tag(
    "area",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'alt',
          description: 'Replacement text for use when images are not available',
        ),
        _Attribute(
          name: 'coords',
          description:
              'Coordinates for the shape to be created in an image map',
        ),
        _Attribute(
          name: 'shape',
          description: 'The kind of shape to be created in an image map',
        ),
        _Attribute(
          name: 'href',
          description: 'Address of the hyperlink',
        ),
        _Attribute(
          name: 'target',
          description: 'Browsing context for hyperlink navigation',
        ),
        _Attribute(
          name: 'download',
          description:
              'Whether to download the resource instead of navigating to it, and its file name if so',
        ),
        _Attribute(
          name: 'ping',
          description: 'URLs to ping',
        ),
        _Attribute(
          name: 'rel',
          description:
              'Relationship between the location in the document containing the hyperlink and the destination resource',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
      ],
    ),
  _Tag("article"),
  _Tag("aside"),
  _Tag("audio")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'crossorigin',
          description: 'How the element handles crossorigin requests',
        ),
        _Attribute(
          name: 'preload',
          description:
              'Hints how much buffering the media resource will likely need',
        ),
        _Attribute(
          name: 'autoplay',
          description:
              'Hint that the media resource can be started automatically when the page is loaded',
        ),
        _Attribute(
          name: 'loop',
          description: 'Whether to loop the media resource',
        ),
        _Attribute(
          name: 'muted',
          description: 'Whether to mute the media resource by default',
        ),
        _Attribute(
          name: 'controls',
          description: 'Show user agent controls',
        ),
      ],
    ),
  _Tag("b"),
  _Tag(
    "base",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'href',
          description: 'Document base URL',
        ),
        _Attribute(
          name: 'target',
          description:
              'Default browsing context for hyperlink navigation and form submission',
        ),
      ],
    ),
  _Tag("bdi"),
  _Tag("bdo"),
  _Tag("big"),
  _Tag("blockquote")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'cite',
          description:
              'Link to the source of the quotation or more information about the edit',
        ),
      ],
    ),
  _Tag("body"),
  _Tag(
    "br",
    isVoidElement: true,
  ),
  _Tag("button")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'autofocus',
          description:
              'Automatically focus the form control when the page is loaded',
        ),
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'formaction',
          description: 'URL to use for form submission',
        ),
        _Attribute(
          name: 'formenctype',
          description: 'Entry list encoding type to use for form submission',
        ),
        _Attribute(
          name: 'formmethod',
          description: 'Variant to use for form submission',
        ),
        _Attribute(
          name: 'formnovalidate',
          description: 'Bypass form control validation for form submission',
        ),
        _Attribute(
          name: 'formtarget',
          description: 'Browsing context for form submission',
        ),
        _Attribute(
          name: 'name',
          description:
              'Name of the element to use for form submission and in the form.elements API',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of button',
        ),
        _Attribute(
          name: 'value',
          description: 'Value to be used for form submission',
        ),
      ],
    ),
  _Tag("canvas")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
      ],
    ),
  _Tag("caption"),
  _Tag("cite"),
  _Tag("code"),
  _Tag(
    "col",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'span',
          description: 'Number of columns spanned by the element',
        ),
      ],
    ),
  _Tag("colgroup")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'span',
          description: 'Number of columns spanned by the element',
        ),
      ],
    ),
  _Tag("data")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'value',
          description: 'Machine-readable value',
        ),
      ],
    ),
  _Tag("datalist"),
  _Tag("dd"),
  _Tag("del")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'cite',
          description:
              'Link to the source of the quotation or more information about the edit',
        ),
        _Attribute(
          name: 'datetime',
          description: 'Date and (optionally) time of the change',
        ),
      ],
    ),
  _Tag("details")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'open',
          description: 'Whether the details are visible',
        ),
      ],
    ),
  _Tag("dfn"),
  _Tag("dialog")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'open',
          description: 'Whether the dialog box is showing',
        ),
      ],
    ),
  _Tag("div"),
  _Tag("dl"),
  _Tag("dt"),
  _Tag("em"),
  _Tag(
    "embed",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of embedded resource',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
      ],
    ),
  _Tag("fieldset")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'disabled',
          description:
              'Whether the descendant form controls, except any inside legend, are disabled',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'name',
          description: 'Name of the element to use in the form.elements API',
        ),
      ],
    ),
  _Tag("figcaption"),
  _Tag("figure"),
  _Tag("footer"),
  _Tag("form")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'accept-charset',
          description: 'Character encodings to use for form submission',
        ),
        _Attribute(
          name: 'action',
          description: 'URL to use for form submission',
        ),
        _Attribute(
          name: 'autocomplete',
          description:
              'Default setting for autofill feature for controls in the form',
        ),
        _Attribute(
          name: 'enctype',
          description: 'Entry list encoding type to use for form submission',
        ),
        _Attribute(
          name: 'method',
          description: 'Variant to use for form submission',
        ),
        _Attribute(
          name: 'name',
          description: 'Name of form to use in the document.forms API',
        ),
        _Attribute(
          name: 'novalidate',
          description: 'Bypass form control validation for form submission',
        ),
        _Attribute(
          name: 'target',
          description: 'Browsing context for form submission',
        ),
      ],
    ),
  _Tag("h1"),
  _Tag("h2"),
  _Tag("h3"),
  _Tag("h4"),
  _Tag("h5"),
  _Tag("h6"),
  _Tag("head"),
  _Tag("header"),
  _Tag("hgroup"),
  _Tag(
    "hr",
    isVoidElement: true,
  ),
  _Tag("html")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'manifest',
          description: 'Application cache manifest',
        ),
      ],
    ),
  _Tag("i"),
  _Tag("iframe")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'srcdoc',
          description: 'A document to render in the iframe',
        ),
        _Attribute(
          name: 'name',
          description: 'Name of nested browsing context',
        ),
        _Attribute(
          name: 'sandbox',
          description: 'Security rules for nested content',
        ),
        _Attribute(
          name: 'allow',
          description: 'Feature policy to be applied to the iframe\'s contents',
        ),
        _Attribute(
          name: 'allowfullscreen',
          description:
              'Whether to allow the iframe\'s contents to use requestFullscreen()',
        ),
        _Attribute(
          name: 'allowpaymentrequest',
          description:
              'Whether the iframe\'s contents are allowed to use the PaymentRequest interface to make payment requests',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
      ],
    ),
  _Tag(
    "img",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'alt',
          description: 'Replacement text for use when images are not available',
        ),
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'srcset',
          description:
              'Images to use in different situations (e.g. high-resolution displays, small monitors, etc)',
        ),
        _Attribute(
          name: 'sizes',
          description: 'Image sizes for different page layouts',
        ),
        _Attribute(
          name: 'crossorigin',
          description: 'How the element handles crossorigin requests',
        ),
        _Attribute(
          name: 'usemap',
          description: 'Name of image map to use',
        ),
        _Attribute(
          name: 'ismap',
          description: 'Whether the image is a server-side image map',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
        _Attribute(
          name: 'decoding',
          description:
              'Decoding hint to use when processing this image for presentation',
        ),
      ],
    ),
  _Tag(
    "input",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'accept',
          description: 'Hint for expected file type in file upload controls',
        ),
        _Attribute(
          name: 'alt',
          description: 'Replacement text for use when images are not available',
        ),
        _Attribute(
          name: 'autocomplete',
          description: 'Hint for form autofill feature',
        ),
        _Attribute(
          name: 'autofocus',
          description:
              'Automatically focus the form control when the page is loaded',
        ),
        _Attribute(
          name: 'checked',
          description: 'Whether the control is checked',
        ),
        _Attribute(
          name: 'dirname',
          description:
              'Name of form control to use for sending the element\'s directionality in form submission',
        ),
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'formaction',
          description: 'URL to use for form submission',
        ),
        _Attribute(
          name: 'formenctype',
          description: 'Entry list encoding type to use for form submission',
        ),
        _Attribute(
          name: 'formmethod',
          description: 'Variant to use for form submission',
        ),
        _Attribute(
          name: 'formnovalidate',
          description: 'Bypass form control validation for form submission',
        ),
        _Attribute(
          name: 'formtarget',
          description: 'Browsing context for form submission',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
        _Attribute(
          name: 'list',
          description: 'List of autocomplete options',
        ),
        _Attribute(
          name: 'max',
          description: 'Maximum value',
        ),
        _Attribute(
          name: 'maxlength',
          description: 'Maximum length of value',
        ),
        _Attribute(
          name: 'min',
          description: 'Minimum value',
        ),
        _Attribute(
          name: 'minlength',
          description: 'Minimum length of value',
        ),
        _Attribute(
          name: 'multiple',
          description: 'Whether to allow multiple values',
        ),
        _Attribute(
          name: 'name',
          description:
              'Name of the element to use for form submission and in the form.elements API',
        ),
        _Attribute(
          name: 'pattern',
          description: 'Pattern to be matched by the form control\'s value',
        ),
        _Attribute(
          name: 'placeholder',
          description:
              'User-visible label to be placed within the form control',
        ),
        _Attribute(
          name: 'readonly',
          description: 'Whether to allow the value to be edited by the user',
        ),
        _Attribute(
          name: 'required',
          description: 'Whether the control is required for form submission',
        ),
        _Attribute(
          name: 'size',
          description: 'Size of the control',
        ),
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'step',
          description: 'Granularity to be matched by the form control\'s value',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of form control',
        ),
        _Attribute(
          name: 'value',
          description: 'Value of the form control',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
      ],
    ),
  _Tag("ins")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'cite',
          description:
              'Link to the source of the quotation or more information about the edit',
        ),
        _Attribute(
          name: 'datetime',
          description: 'Date and (optionally) time of the change',
        ),
      ],
    ),
  _Tag("kbd"),
  _Tag("keygen"),
  _Tag("label")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'for',
          description: 'Associate the label with form control',
        ),
      ],
    ),
  _Tag("legend"),
  _Tag("li"),
  _Tag(
    "link",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'href',
          description: 'Address of the hyperlink',
        ),
        _Attribute(
          name: 'crossorigin',
          description: 'How the element handles crossorigin requests',
        ),
        _Attribute(
          name: 'rel',
          description:
              'Relationship between the document containing the hyperlink and the destination resource',
        ),
        _Attribute(
          name: 'media',
          description: 'Applicable media',
        ),
        _Attribute(
          name: 'integrity',
          description:
              'Integrity metadata used in Subresource Integrity checks [SRI]',
        ),
        _Attribute(
          name: 'hreflang',
          description: 'Language of the linked resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Hint for the type of the referenced resource',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
        _Attribute(
          name: 'sizes',
          description: 'Sizes of the icons (for rel="icon")',
        ),
        _Attribute(
          name: 'as',
          description:
              'Potential destination for a preload request (for rel="preload" and rel="modulepreload")',
        ),
        _Attribute(
          name: 'color',
          description:
              'Color to use when customizing a site\'s icon (for rel="mask-icon")',
        ),
      ],
    ),
  _Tag("main"),
  _Tag("map")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'name',
          description:
              'Name of image map to reference from the usemap attribute',
        ),
      ],
    ),
  _Tag("mark"),
  _Tag("marquee"),
  _Tag("menu"),
  _Tag("menuitem"),
  _Tag(
    "meta",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'name',
          description: 'Metadata name',
        ),
        _Attribute(
          name: 'http-equiv',
          description: 'Pragma directive',
        ),
        _Attribute(
          name: 'content',
          description: 'Value of the element',
        ),
        _Attribute(
          name: 'charset',
          description: 'Character encoding declaration',
        ),
      ],
    ),
  _Tag("meter")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'value',
          description: 'Current value of the element',
        ),
        _Attribute(
          name: 'min',
          description: 'Lower bound of range',
        ),
        _Attribute(
          name: 'max',
          description: 'Upper bound of range',
        ),
        _Attribute(
          name: 'low',
          description: 'High limit of low range',
        ),
        _Attribute(
          name: 'high',
          description: 'Low limit of high range',
        ),
        _Attribute(
          name: 'optimum',
          description: 'Optimum value in gauge',
        ),
      ],
    ),
  _Tag("nav"),
  _Tag("noscript"),
  _Tag("object")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'data',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of embedded resource',
        ),
        _Attribute(
          name: 'typemustmatch',
          description:
              'Whether the type attribute and the Content-Type value need to match for the resource to be used',
        ),
        _Attribute(
          name: 'name',
          description: 'Name of nested browsing context',
        ),
        _Attribute(
          name: 'usemap',
          description: 'Name of image map to use',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
      ],
    ),
  _Tag("ol")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'reversed',
          description: 'Number the list backwards',
        ),
        _Attribute(
          name: 'start',
          description: 'Starting value of the list',
        ),
        _Attribute(
          name: 'type',
          description: 'Kind of list marker',
        ),
      ],
    ),
  _Tag("optgroup")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'label',
          description: 'User-visible label',
        ),
      ],
    ),
  _Tag("option")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'label',
          description: 'User-visible label',
        ),
        _Attribute(
          name: 'selected',
          description: 'Whether the option is selected by default',
        ),
        _Attribute(
          name: 'value',
          description: 'Value to be used for form submission',
        ),
      ],
    ),
  _Tag("output")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'for',
          description:
              'Specifies controls from which the output was calculated',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'name',
          description: 'Name of the element to use in the form.elements API',
        ),
      ],
    ),
  _Tag("p"),
  _Tag(
    "param",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'name',
          description: 'Name of parameter',
        ),
        _Attribute(
          name: 'value',
          description: 'Value of parameter',
        ),
      ],
    ),
  _Tag("picture"),
  _Tag("pre"),
  _Tag("progress")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'value',
          description: 'Current value of the element',
        ),
        _Attribute(
          name: 'max',
          description: 'Upper bound of range',
        ),
      ],
    ),
  _Tag("q")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'cite',
          description:
              'Link to the source of the quotation or more information about the edit',
        ),
      ],
    ),
  _Tag("rp"),
  _Tag("rt"),
  _Tag("ruby"),
  _Tag("s"),
  _Tag("samp"),
  _Tag("script")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of script',
        ),
        _Attribute(
          name: 'nomodule',
          description:
              'Prevents execution in user agents that support module scripts',
        ),
        _Attribute(
          name: 'async',
          description: 'Execute script when available, without blocking',
        ),
        _Attribute(
          name: 'defer',
          description: 'Defer script execution',
        ),
        _Attribute(
          name: 'crossorigin',
          description: 'How the element handles crossorigin requests',
        ),
        _Attribute(
          name: 'integrity',
          description:
              'Integrity metadata used in Subresource Integrity checks [SRI]',
        ),
        _Attribute(
          name: 'referrerpolicy',
          description: 'Referrer policy for fetches initiated by the element',
        ),
      ],
    ),
  _Tag("section"),
  _Tag("select")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'autocomplete',
          description: 'Hint for form autofill feature',
        ),
        _Attribute(
          name: 'autofocus',
          description:
              'Automatically focus the form control when the page is loaded',
        ),
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'multiple',
          description: 'Whether to allow multiple values',
        ),
        _Attribute(
          name: 'name',
          description:
              'Name of the element to use for form submission and in the form.elements API',
        ),
        _Attribute(
          name: 'required',
          description: 'Whether the control is required for form submission',
        ),
        _Attribute(
          name: 'size',
          description: 'Size of the control',
        ),
      ],
    ),
  _Tag("small"),
  _Tag(
    "source",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'type',
          description: 'Type of embedded resource',
        ),
        _Attribute(
          name: 'srcset',
          description:
              'Images to use in different situations (e.g. high-resolution displays, small monitors, etc)',
        ),
        _Attribute(
          name: 'sizes',
          description: 'Image sizes for different page layouts',
        ),
        _Attribute(
          name: 'media',
          description: 'Applicable media',
        ),
      ],
    ),
  _Tag("span"),
  _Tag("strong"),
  _Tag("style")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'media',
          description: 'Applicable media',
        ),
      ],
    ),
  _Tag("sub"),
  _Tag("summary"),
  _Tag("sup"),
  _Tag("table"),
  _Tag("tbody"),
  _Tag("td")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'colspan',
          description: 'Number of columns that the cell is to span',
        ),
        _Attribute(
          name: 'rowspan',
          description: 'Number of rows that the cell is to span',
        ),
        _Attribute(
          name: 'headers',
          description: 'The header cells for this cell',
        ),
      ],
    ),
  _Tag("textarea")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'autocomplete',
          description: 'Hint for form autofill feature',
        ),
        _Attribute(
          name: 'autofocus',
          description:
              'Automatically focus the form control when the page is loaded',
        ),
        _Attribute(
          name: 'cols',
          description: 'Maximum number of characters per line',
        ),
        _Attribute(
          name: 'dirname',
          description:
              'Name of form control to use for sending the element\'s directionality in form submission',
        ),
        _Attribute(
          name: 'disabled',
          description: 'Whether the form control is disabled',
        ),
        _Attribute(
          name: 'form',
          description: 'Associates the element with a form element',
        ),
        _Attribute(
          name: 'maxlength',
          description: 'Maximum length of value',
        ),
        _Attribute(
          name: 'minlength',
          description: 'Minimum length of value',
        ),
        _Attribute(
          name: 'name',
          description:
              'Name of the element to use for form submission and in the form.elements API',
        ),
        _Attribute(
          name: 'placeholder',
          description:
              'User-visible label to be placed within the form control',
        ),
        _Attribute(
          name: 'readonly',
          description: 'Whether to allow the value to be edited by the user',
        ),
        _Attribute(
          name: 'required',
          description: 'Whether the control is required for form submission',
        ),
        _Attribute(
          name: 'rows',
          description: 'Number of lines to show',
        ),
        _Attribute(
          name: 'wrap',
          description:
              'How the value of the form control is to be wrapped for form submission',
        ),
      ],
    ),
  _Tag("tfoot"),
  _Tag("th")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'colspan',
          description: 'Number of columns that the cell is to span',
        ),
        _Attribute(
          name: 'rowspan',
          description: 'Number of rows that the cell is to span',
        ),
        _Attribute(
          name: 'headers',
          description: 'The header cells for this cell',
        ),
      ],
    ),
  _Tag("thead"),
  _Tag("time")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'datetime',
          description: 'Machine-readable value',
        ),
      ],
    ),
  _Tag("title"),
  _Tag("tr"),
  _Tag(
    "track",
    isVoidElement: true,
  )..attributes.addAll(
      [
        _Attribute(
          name: 'kind',
          description: 'The type of text track',
        ),
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'srclang',
          description: 'Language of the text track',
        ),
        _Attribute(
          name: 'label',
          description: 'User-visible label',
        ),
        _Attribute(
          name: 'default',
          description:
              'Enable the track if no other text track is more suitable',
        ),
      ],
    ),
  _Tag("u"),
  _Tag("ul"),
  _Tag("var"),
  _Tag("video")
    ..attributes.addAll(
      [
        _Attribute(
          name: 'src',
          description: 'Address of the resource',
        ),
        _Attribute(
          name: 'crossorigin',
          description: 'How the element handles crossorigin requests',
        ),
        _Attribute(
          name: 'poster',
          description: 'Poster frame to show prior to video playback',
        ),
        _Attribute(
          name: 'preload',
          description:
              'Hints how much buffering the media resource will likely need',
        ),
        _Attribute(
          name: 'autoplay',
          description:
              'Hint that the media resource can be started automatically when the page is loaded',
        ),
        _Attribute(
          name: 'playsinline',
          description:
              'Encourage the user agent to display video content within the element\'s playback area',
        ),
        _Attribute(
          name: 'loop',
          description: 'Whether to loop the media resource',
        ),
        _Attribute(
          name: 'muted',
          description: 'Whether to mute the media resource by default',
        ),
        _Attribute(
          name: 'controls',
          description: 'Show user agent controls',
        ),
        _Attribute(
          name: 'width',
          description: 'Horizontal dimension',
        ),
        _Attribute(
          name: 'height',
          description: 'Vertical dimension',
        ),
      ],
    ),
  _Tag(
    "wbr",
    isVoidElement: true,
  ),
  _Tag("circle"),
  _Tag("clipPath"),
  _Tag("defs"),
  _Tag("ellipse"),
  _Tag("foreignObject"),
  _Tag("g"),
  _Tag("image"),
  _Tag("line"),
  _Tag("linearGradient"),
  _Tag("mask"),
  _Tag("path"),
  _Tag("pattern"),
  _Tag("polygon"),
  _Tag("polyline"),
  _Tag("radialGradient"),
  _Tag("rect"),
  _Tag("stop"),
  _Tag("svg"),
  _Tag("text"),
  _Tag("tspan"),
];
